summaryrefslogtreecommitdiffstats
path: root/src/kvilib/core/kvi_string.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/kvilib/core/kvi_string.cpp')
-rw-r--r--src/kvilib/core/kvi_string.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/kvilib/core/kvi_string.cpp b/src/kvilib/core/kvi_string.cpp
index df89122a..3eb7fa67 100644
--- a/src/kvilib/core/kvi_string.cpp
+++ b/src/kvilib/core/kvi_string.cpp
@@ -2203,7 +2203,7 @@ int KviStr::occurences(const char *str,bool caseS) const
return cnt;
}
-bool KviStr::tqcontains(char c,bool caseS) const
+bool KviStr::contains(char c,bool caseS) const
{
register char *p = m_ptr;
if(caseS)
@@ -2224,7 +2224,7 @@ bool KviStr::tqcontains(char c,bool caseS) const
return false;
}
-bool KviStr::tqcontains(const char *str,bool caseS) const
+bool KviStr::contains(const char *str,bool caseS) const
{
__range_valid(str);
register char *p = m_ptr;
@@ -2657,7 +2657,7 @@ KviStr & KviStr::sprintf(const char *fmt,...)
return (*this);
}
-int KviStr::tqfind(const char *str,int idx,bool caseS) const
+int KviStr::find(const char *str,int idx,bool caseS) const
{
if(idx >= m_len)return -1;
register char *p=m_ptr + idx;
@@ -2682,7 +2682,7 @@ int KviStr::tqfind(const char *str,int idx,bool caseS) const
}
}
-int KviStr::tqfind(char c,int idx) const
+int KviStr::find(char c,int idx) const
{
if(idx >= m_len)return -1;
register char *p=m_ptr + idx;
@@ -2691,7 +2691,7 @@ int KviStr::tqfind(char c,int idx) const
}
-int KviStr::tqfindRev(const char *str,int idx,bool caseS) const
+int KviStr::findRev(const char *str,int idx,bool caseS) const
{
if((m_len + idx) < 0)return -1;
register char *p=m_ptr + m_len + idx;
@@ -2729,10 +2729,10 @@ int KviStr::findFirstIdx(const char *str,bool caseS) const
{
// This function can't be used to search inside
// multibyte encoded strings... convert your
// code to TQString and use TQString::tqfindRev().
// We must throw away KviStr at all in this case...
- // return TQString(m_ptr).tqfind(TQString(str),0,caseS);;
+ // return TQString(m_ptr).find(TQString(str),0,caseS);;
// Both this KviStr and the const char * str are assumed
// to be in the proper (and same) encoding.
@@ -2782,10 +2782,10 @@ int KviStr::findLastIdx(const char *str,bool caseS) const
{
// This function can't be used to search inside
// multibyte encoded strings... convert your
// code to TQString and use TQString::tqfindRev().
// We must throw away KviStr at all in this case...
- // return TQString(m_ptr).tqfindRev(TQString(str),-1,caseS);
+ // return TQString(m_ptr).findRev(TQString(str),-1,caseS);
__range_valid(str);
//Calc the len of the searched string
@@ -2948,7 +2948,7 @@ KviStr & KviStr::emptyString()
}
-bool KviStr::ext_tqcontains(register const char * data,const char * item,bool caseS)
+bool KviStr::ext_contains(register const char * data,const char * item,bool caseS)
{
if(item && data)
{
@@ -2729,10 +2729,10 @@ int KviStr::findFirstIdx(const char *str,bool caseS) const
// This function can't be used to search inside
// multibyte encoded strings... convert your
- // code to TQString and use TQString::tqfindRev().
+ // code to TQString and use TQString::findRev().
// We must throw away KviStr at all in this case...
@@ -2782,10 +2782,10 @@ int KviStr::findLastIdx(const char *str,bool caseS) const
// This function can't be used to search inside
// multibyte encoded strings... convert your
- // code to TQString and use TQString::tqfindRev().
+ // code to TQString and use TQString::findRev().
// We must throw away KviStr at all in this case...